@@ -1,12 +1,13 @@
 __all__ = [
+    "OnnxRegistry",
+    "analyze",
+    "export",
     "exported_program_to_ir",
     "patch_torch",
     "unpatch_torch",
-    "analyze",
-    "OnnxRegistry",
 ]
 
 from ._patch import patch_torch, unpatch_torch
-from ._core import exported_program_to_ir
+from ._core import exported_program_to_ir, export
 from ._analysis import analyze
 from ._registration import OnnxRegistry
