@@ -28,6 +28,7 @@ from torch.export import graph_signature
 
 from torch_onnx import (
     _building,
+    _capture_strategies,
     _decomp,
     _dispatching,
     _fx_passes,
@@ -37,8 +38,6 @@ from torch_onnx import (
     _registration,
     _reporting,
     _tensors,
-    _torchscript_converter,
-    _capture_strategies,
     errors,
 )
 
@@ -129,6 +128,12 @@ def _set_shape_types(
     meta_vals: Sequence[torch.Tensor],
     complex_to_float: bool = True,
 ):
+    if not isinstance(meta_vals, Sequence):
+        logger.warning(
+            "Expected meta_vals to be a sequence, but got %s. There may be an internal error.",
+            meta_vals,
+        )
+        meta_vals = (meta_vals,)
     for value, meta_val in zip(values, meta_vals):
         _set_shape_type(value, meta_val, complex_to_float=complex_to_float)
 
@@ -210,7 +215,10 @@ def _get_node_namespace(node: torch.fx.Node) -> tuple[str, list[str], list[str]]
     nn_module_stack = node.meta.get("nn_module_stack")
     logger.debug("%s", nn_module_stack)
     if nn_module_stack is None:
-        logger.warning("nn_module_stack not found for node %s", node.name)
+        logger.warning(
+            "nn_module_stack not found for node '%s'. Skip adding metadata...",
+            node.name,
+        )
         return f"{node.name}: {node.target}", [str(node.target)], [node.name]
     namespaces = []
     class_hierarchy = []
@@ -665,6 +673,14 @@ def exported_program_to_ir(
                 "": registry.opset_version,
             },
             name="main_graph",
+            metadata_props={
+                "pkg.torch.export.ExportedProgram.graph_signature": str(
+                    exported_program.graph_signature
+                ),
+                "pkg.torch.export.ExportedProgram.range_constraints": str(
+                    exported_program.range_constraints
+                ),
+            },
         ),
         ir_version=9,
         producer_name="torch",
@@ -711,6 +727,10 @@ def exported_program_to_ir(
         persistent = spec.persistent
         value = values[value_name]
 
+        assert not isinstance(
+            value, Sequence
+        ), f"Input '{value_name}' should not be a sequence. This is unexpected."
+
         value.metadata_props["pkg.torch.export.graph_signature.InputSpec.kind"] = (
             input_kind.name
         )
@@ -741,18 +761,29 @@ def exported_program_to_ir(
         output_kind = spec.kind
         value = values[value_name]
 
-        if not isinstance(value, ir.Value):
+        if not isinstance(value, (ir.Value, Sequence)):
             raise TypeError(
                 f"Output '{value_name}' should be an ir.Value. Actual type is '{type(value)}': {value!r}. "
                 "This may be due to an incorrect implementation of the ONNX function that produced this output."
             )
 
-        value.metadata_props["pkg.torch.export.graph_signature.OutputSpec.kind"] = (
-            output_kind.name
-        )
+        # The output value may be a sequence, meaning the operator has multiple outputs
+        _values = (value,) if not isinstance(value, Sequence) else value
 
-        if output_kind == graph_signature.OutputKind.USER_OUTPUT:
-            model.graph.outputs.append(value)
+        if len(_values) > 1:
+            logger.warning(
+                "Model output '%s' has multiple values: %s (output spec: %s). Please make sure this is expected.",
+                value_name,
+                _values,
+                spec,
+            )
+
+        for value in _values:
+            value.metadata_props["pkg.torch.export.graph_signature.OutputSpec.kind"] = (
+                output_kind.name
+            )
+            if output_kind == graph_signature.OutputKind.USER_OUTPUT:
+                model.graph.outputs.append(value)
 
     # 4. Rename the initializers to match the tensor names
     for name, param_name in itertools.chain(
@@ -815,7 +846,11 @@ def _verbose_printer(verbose: bool | None) -> Callable[..., None]:
 
 
 def export(
-    model: torch.nn.Module | torch.export.ExportedProgram,
+    model: torch.nn.Module
+    | torch.export.ExportedProgram
+    | torch.fx.GraphModule
+    | torch.jit.ScriptModule
+    | torch.jit.ScriptFunction,
     args: tuple[Any, ...],
     kwargs: dict[str, Any] | None = None,
     *,
@@ -867,53 +902,12 @@ def export(
     # Step 1: Export the model with torch.export.export if the model is not already an ExportedProgram
     if isinstance(model, torch.export.ExportedProgram):
         program = model
-    elif isinstance(model, (torch.jit.ScriptModule, torch.jit.ScriptFunction)):
-        model_repr = _take_first_line(repr(model))
-        verbose_print(
-            f"Obtain model graph for `{model_repr}` with `TorchScript to ExportedProgram converter` because model is jit'ed..."
-        )
-        try:
-            program = _torchscript_converter.TS2EPConverter(
-                model, args, kwargs
-            ).convert()
-            verbose_print(
-                f"Obtain model graph for `{model_repr}` with `TorchScript to ExportedProgram converter` because model is jit'ed... ✅"
-            )
-        except Exception as e:
-            verbose_print(
-                f"Obtain model graph for `{model_repr}` with `TorchScript to ExportedProgram converter` because model is jit'ed... ❌"
-            )
-            profile_result = _maybe_stop_profiler_and_get_result(profiler)
-            export_status.torch_jit = False
-
-            if error_report:
-                error_report_path = (
-                    artifacts_dir / f"onnx_export_{timestamp}_pt_export.md"
-                )
-                _reporting.create_torch_export_error_report(
-                    error_report_path,
-                    _format_exception(e),
-                    export_status=export_status,
-                    profile_result=profile_result,
-                )
-            else:
-                error_report_path = None
-
-            raise errors.TorchScriptConverterError(
-                textwrap.dedent(f"""\
-                    Failed to export the model with TorchScript converter. {_BLUE}This is step 1/2{_END} of exporting the model to ONNX. Next steps:
-                    - Create an issue in the PyTorch GitHub repository against the {_BLUE}*torch.export*{_END} component and attach the full error stack as well as reproduction scripts.""")
-                + (
-                    f"\nError report has been saved to '{error_report_path}'."
-                    if error_report
-                    else ""
-                )
-                + _summarize_exception_stack(e)
-            ) from e
+        export_status.torch_export = True
     else:
         failed_results: list[_capture_strategies.Result] = []
         # Convert an nn.Module to an ExportedProgram
         # Try everything 🐰 (all paths for getting an ExportedProgram)
+        # When input is a JIT module, the last strategy will succeed so it is handled
         for strategy_class in _capture_strategies.CAPTURE_STRATEGIES:
             strategy = strategy_class(
                 verbose=verbose is not False,  # Treat None as verbose
@@ -931,13 +925,13 @@ def export(
             elif strategy_class is _capture_strategies.JitTraceConvertStrategy:
                 export_status.torch_jit = result.success
 
-            if result.success:
+            if result.exported_program is not None:
                 program = result.exported_program
                 break
             else:
                 failed_results.append(result)
 
-        if not result.success:
+        if result.exported_program is None:
             # If all strategies fail, produce an error report and raise the first error
             profile_result = _maybe_stop_profiler_and_get_result(profiler)
 
@@ -976,7 +970,7 @@ def export(
                 + _summarize_exception_stack(first_error)
             ) from first_error
 
-    assert program
+    assert program is not None
 
     if dump_exported_program:
         verbose_print("Dumping ExportedProgram because `dump_exported_program=True`...")
