@@ -10,12 +10,6 @@ class TorchExportError(ExporterError):
     pass
 
 
-class TorchScriptConverterError(ExporterError):
-    """Error during torchscript -> ExportedProgram conversion."""
-
-    pass
-
-
 class OnnxConversionError(ExporterError):
     """Error during ONNX conversion."""
 
